/*
 *  CCSprite.cpp
 *  iDemo
 *
 *  Created by Dr.Watson on 31/05/08.
 *  Copyright 2008 (c) Dr.Watson. All rights reserved.
 *
 */

#include "CCSprite.h"
#include "CCTexture.h"
#include "Wrapper.h"


CCSprite::CCSprite(CCTexture *texture, float x, float y, float width, float height)
{
	mTexture = texture;
	mX = x;
	mY = y;
	mWidth = width;
	mHeight = height;
	
	mRed = 1.0f;
	mGreen = 1.0f;
	mBlue = 1.0f;
	mAlpha = 1.0f;
}


CCSprite::~CCSprite()
{
}


void CCSprite::render(float x, float y, float angle, float xScale, float yScale)
{
	y = SCREEN_HEIGHT-y;		// for OpenGL ES, (0,0) is at lower left corner!
	
	GLfloat _minU = mX/mTexture->getTextureWidth();
	GLfloat _maxU = (mX+mWidth)/mTexture->getTextureWidth();
	GLfloat _minV = mY/mTexture->getTextureHeight();
	GLfloat _maxV = (mY+mHeight)/mTexture->getTextureHeight();
	
	GLfloat	coordinates[] = 
	{
		_minU,	_maxV,
		_maxU,	_maxV,
		_minU,	_minV,
		_maxU,	_minV
	};
	
	GLfloat	xx = - mWidth/2;
	GLfloat yy = - mHeight/2;
	
	GLfloat	vertices[] = 
	{
		xx,			yy,				
		xx+mWidth,	yy,				
		xx,			yy+mHeight,
		xx+mWidth,	yy+mHeight	
	};
	
	mTexture->bind();
	
	glColor4f(mRed, mGreen, mBlue, mAlpha);
	
	glPushMatrix();
	glTranslatef(x, y, 0.0f);
	glRotatef(angle, 0.0f, 0.0f, 1.0f);
	glScalef(xScale, yScale, 1.0f);
	glVertexPointer(2, GL_FLOAT, 0, vertices);
	glTexCoordPointer(2, GL_FLOAT, 0, coordinates);
	glDrawArrays(GL_TRIANGLE_STRIP, 0, 4);
	glPopMatrix();
	
	glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
	
}


void CCSprite::setColor(float r, float g, float b, float a)
{
	mRed = r;
	mGreen = g;
	mBlue = b;
	mAlpha = a;
}
